<?php

use Icinga\Web\Controller;

class HelloWorld_UniverseController extends Controller
{
    /**
     * Initialize this controller
     */
    public function init()
    {
        $this->assertPermission('helloworld/universe');
    }

    /**
     * Return the names of all permitted galaxies
     *
     * @return  array
     */
    protected function listPermittedGalaxies()
    {
        $providedGalaxies = array('Milky Way', 'Andromeda');
        foreach ($this->getRestrictions('helloworld/filter/galaxy') as $filter) {
            $permitted = explode(',', $filter);
            $providedGalaxies = array_intersect($providedGalaxies, array_map('trim', $permitted));
        }

        return $providedGalaxies;
    }

    /**
     * Say hello to the universe
     */
    public function indexAction()
    {
        $this->getTabs()->activate('universe');
        $this->view->galaxies = $this->listPermittedGalaxies();
    }

    /**
     * Say hello to the galaxy given in the request
     */
    public function galaxyAction()
    {
        $galaxy = $this->params->getRequired('galaxy');
        $this->view->galaxy = $galaxy;
    }

    /**
     * Return the tabs
     *
     * @return Tabs
     */
    public function getTabs()
    {
        $tabs = parent::getTabs();
        $tabs->add(
            'world',
            array(
                'title' => 'World',
                'url'   => 'helloworld'
            )
        );
        $tabs->add(
            'universe',
            array(
                'title' => 'Universe',
                'url'   => 'helloworld/universe'
            )
        );

        return $tabs;
    }
}
